@@ -41,7 +41,6 @@ Check the LICENSE file for details.
 #![doc(html_root_url = "https://docs.rs/juniper_warp/0.2.0")]
 
 use anyhow::anyhow;
-use bytes::Bytes;
 use futures::{FutureExt as _, TryFutureExt};
 use juniper::{
     http::{GraphQLBatchRequest, GraphQLRequest},
@@ -49,7 +48,7 @@ use juniper::{
 };
 use std::{collections::HashMap, str, sync::Arc};
 use tokio::task;
-use warp::{body, filters::BoxedFilter, http, query, Filter};
+use warp::{body, filters::BoxedFilter, http, hyper::body::Bytes, query, Filter};
 
 /// Make a filter for graphql queries/mutations.
 ///
@@ -717,7 +716,7 @@ mod tests_http_harness {
         }
 
         fn make_request(&self, req: warp::test::RequestBuilder) -> TestResponse {
-            let mut rt = tokio::runtime::Runtime::new().expect("Failed to create tokio::Runtime");
+            let rt = tokio::runtime::Runtime::new().expect("Failed to create tokio::Runtime");
             make_test_response(rt.block_on(async move {
                 req.filter(&self.filter).await.unwrap_or_else(|rejection| {
                     let code = if rejection.is_not_found() {
